# Realm 1

Demo realm instance with 50 members, 5 organizations, 100 transactions, and 10 disputes.

## Realm-Specific Files

| File | Description |
|------|-------------|
| `manifest.json` | Realm configuration (name: "Realm 1", seed: 1) |
| `logo.svg` | Realm-specific logo |
| `canister_ids.json` | Deployment canister IDs |

## Shared Codex Files

Common codex files are stored in `../realm_common/` and automatically copied to generated realms during `realms realm create`.

See `../realm_common/README.md` for documentation on shared files.
